import { csv, select } from 'd3';
import { scatterPlot } from './scatterPlot';

const csvUrl = [
  'https://gist.githubusercontent.com/curran/a08a1080b88344b0c8a7/raw/0e7a9b0a5d22642a06d3d5b9bcbad9890c8ee534/iris.csv', // // URL Link which we got from gist.github
].join(''); // Join is used for adding the sepal,petal length and width
const parseRow = (d) => {
  d.sepal_length = +d.sepal_length;
  d.sepal_width = +d.sepal_width;
  d.petal_length = +d.petal_length;
  d.petal_width = +d.petal_width; //This represents x-axis and y-axis of Reusable scatter plot
  return d;
};
// window is a global variable it shows which script is running
const width = window.innerWidth;
const height = window.innerHeight;
const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

// selecting the specified species
const xValue = (d) => d.petal_length;
const yValue = (d) => d.petal_width;
const rxValue = (d) => d.sepal_length;
const ryValue = (d) => d.sepal_width;
const speciesValue = (d) => d.species;

// Code using the csv and url files
const main = async () => {
  const data = await csv(csvUrl, parseRow);
  const x = xValue((d) => d.petal_width);
  const y = yValue((d) => d.sepal_length);
  const marker = (d) => {
        	switch(d){
            case 'versicolor':
              return 'yellow';
            case 'virginica':
              return 'lightblue';
            default:
              return 'orange'; // The specified color for species is selected
          }
        }
  
  const marks = data.map((d) => ({
          x: xValue((d) => d.petal_width),
          y: yValue((d) => d.sepal_length),
          species: speciesValue(d),
          color: marker(speciesValue(d)),
        	rx: rxValue(d),
          ry: ryValue(d), // Mapping function is used for data to run the required fields
                      
        }));
  
  const plot = scatterPlot()
    .width(width)
    .height(height)
    .data(await csv(csvUrl, parseRow))
    .xValue((d) => d.petal_width)
    .yValue((d) => d.sepal_length)
    .margin({
      top: 30,
      right: 15,
      bottom: 95,
      left: 90, // The values are given according to the requirements
    })
    .radius(6);
  
svg
          .selectAll('circle')
          .data(marks)
          .join('circle')
          .attr('cx', (d) => d.x)
          .attr('cy', (d) => d.y)
        	.attr('fill', (d) => d.color)
        	.attr('rx', (d) => (d.rx))
        	.attr('ry', (d) => (d.ry));
  
    svg.append("text")
        .attr("x",-250)
        .attr("y",20)
        .attr("font-size","14px")
        .attr("transform","rotate(-90)")
        .text("Sepal Length")      //for adding the Y lable 
        
       
    svg.append("text")
        .attr("x",500)
        .attr("y",500)
        .attr("font-size","14px")
        .text("Petal width")  // for adding the X lable

  
  const columns = [
    'petal_width',
    'sepal_width',
    'petal_length',
    'sepal_length',
  ];
  // By calling the function to svg file to get the scatter plot
  let i = 0;
  setInterval(() => {
    plot.xValue((d) => d[columns[i % columns.length]]);
    svg.call(plot);
    i++;
  }, 2000);
};
main();
